@@ -884,11 +884,17 @@ int open_target(char* target, cmd_opt* opt) {
 		    ddd_block_device = 1;
 		else
 		    ddd_block_device = 0;
-	    }else{
+	    } else {
 		ddd_block_device = 0;   
 	    }
+
 	    log_mesg(1, 0, 0, debug, "ddd target file(0) or device(1) ? %i \n", ddd_block_device);
 	}
+
+	if (opt->restore_raw_file == 1) {
+	    ddd_block_device = 0;
+	}
+
 	if (opt->clone || opt->domain || (ddd_block_device == 0)) {
 		if (strcmp(target, "-") == 0) {
 			if ((ret = fileno(stdout)) == -1)
@@ -1052,6 +1058,8 @@ void print_opt(cmd_opt opt) {
 		log_mesg(1, 0, 0, debug, "MODE: device to device\n");
 	else if (opt.domain)
 		log_mesg(1, 0, 0, debug, "MODE: create domain log for ddrescue\n");
+	else if (opt.ddd)
+		log_mesg(1, 0, 0, debug, "MODE: work like command dd\n");
 
 	log_mesg(1, 0, 0, debug, "DEBUG: %i\n", opt.debug);
 	log_mesg(1, 0, 0, debug, "SOURCE: %s\n", opt.source);
@@ -1087,8 +1095,12 @@ void print_partclone_info(cmd_opt opt) {
 		log_mesg(0, 0, 1, debug, _("Starting to back up device(%s) to device(%s)\n"), opt.source, opt.target);
 	else if (opt.domain)
 		log_mesg(0, 0, 1, debug, _("Starting to map device (%s) to domain log (%s)\n"), opt.source, opt.target);
+	else if (opt.ddd)
+		log_mesg(0, 0, 1, debug, _("Starting to clone/restore (%s) to (%s) with dd mode\n"), opt.source, opt.target);
+	else if (opt.info)
+		log_mesg(0, 0, 1, debug, _("Display image information\n"));
 	else
-		log_mesg(0, 0, 1, debug, "unknow mode\n");
+		log_mesg(0, 0, 1, debug, "Unknown mode\n");
 }
 
 /// print image head
